Module: AvaTax::Client::Addresses
- Included in:
- AvaTax::Client
- Defined in:
- lib/avatax/client/addresses.rb
Instance Method Summary collapse
-
#resolve_address(options = {}) ⇒ Object
Retrieve geolocation information for a specified address.
-
#resolve_address_post(model) ⇒ Object
Retrieve geolocation information for a specified address.
Instance Method Details
#resolve_address(options = {}) ⇒ Object
Retrieve geolocation information for a specified address
Resolve an address against Avalara's address-validation system. If the address can be resolved, this API provides the latitude and longitude of the resolved location. The value 'resolutionQuality' can be used to identify how closely this address can be located. If the address cannot be clearly located, use the 'messages' structure to learn more about problems with this address. This is the same API as the POST /api/v2/addresses/resolve endpoint. Both verbs are supported to provide for flexible implementation.
In order to get any evaluation for an address, please provide at least one of the following fields/pairs:
- postal code
- line1 + city + region
- line1 + postal code
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AutoAddress. Swagger Name: AvaTaxClient
34 35 |
# File 'lib/avatax/client/addresses.rb', line 34 def resolve_address(={}) path = "/api/v2/addresses/resolve" get(path, , "22.2.1") end |
#resolve_address_post(model) ⇒ Object
Retrieve geolocation information for a specified address
Resolve an address against Avalara's address-validation system. If the address can be resolved, this API provides the latitude and longitude of the resolved location. The value 'resolutionQuality' can be used to identify how closely this address can be located. If the address cannot be clearly located, use the 'messages' structure to learn more about problems with this address. This is the same API as the GET /api/v2/addresses/resolve endpoint. Both verbs are supported to provide for flexible implementation.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AutoAddress. Swagger Name: AvaTaxClient
53 54 |
# File 'lib/avatax/client/addresses.rb', line 53 def resolve_address_post(model) path = "/api/v2/addresses/resolve" post(path, model, {}, "22.2.1") end |