Module: AvaTax::Client::FormTypeMapping
- Defined in:
- lib/avatax/client/formtypemapping.rb
Instance Method Summary collapse
-
#resolve_form_type_task(options = {}) ⇒ Object
Resolves a form type to an extraction task identifier.
Instance Method Details
#resolve_form_type_task(options = {}) ⇒ Object
Resolves a form type to an extraction task identifier.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
15 16 |
# File 'lib/avatax/client/formtypemapping.rb', line 15 def resolve_form_type_task(={}) path = "/api/v2/form-type-mappings/resolve-task" get(path, , AvaTax::VERSION) end |