Method: AvaTax::Client::MultiDocument#commit_multi_document_transaction

Defined in:
lib/avatax/client/multidocument.rb

#commit_multi_document_transaction(model) ⇒ Object

Commit a MultiDocument transaction

Marks a list of transactions by changing its status to Committed.

Transactions that are committed are available to be reported to a tax authority by Avalara Managed Returns.

A transaction represents a unique potentially taxable action that your company has recorded, and transactions include actions like sales, purchases, inventory transfer, and returns (also called refunds).

Any changes made to a committed transaction will generate a transaction history.

NOTE: If your companyCode or transactionCode contains any of these characters /, +, ? or a space please use the following encoding before making a request:

  • Replace '/' with '_-ava2f-_' For example: document/Code becomes document_-ava2f-_Code
  • Replace '+' with '_-ava2b-_' For example: document+Code becomes document_-ava2b-_Code
  • Replace '?' with '_-ava3f-_' For example: document?Code becomes document_-ava3f-_Code
  • Replace '%' with '_-ava25-_' For example: document%Code becomes document_-ava25-_Code
  • Replace '#' with '_-ava23-_' For example: document#Code becomes document_-ava23-_Code
  • Replace ' ' with '%20' For example: document Code becomes document%20Code

Security Policies

  • This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, ProStoresOperator, SSTAdmin, TechnicalSupportAdmin.
  • This API depends on the following active services:Required (all): AvaTaxPro. Swagger Name: AvaTaxClient

Parameters:

  • model (Object)

    The commit request you wish to execute

Returns:

  • (Object)


102
103
# File 'lib/avatax/client/multidocument.rb', line 102

def commit_multi_document_transaction(model)        path = "/api/v2/transactions/multidocument/commit"
post(path, model, {}, AvaTax::VERSION)      end