Module: AvaTax::Client::Provisioning
- Defined in:
- lib/avatax/client/provisioning.rb
Instance Method Summary collapse
-
#request_new_account(model) ⇒ Object
Request a new Avalara account.
-
#request_new_entitlement(id, offer) ⇒ Object
Request a new entitilement to an existing customer.
Instance Method Details
#request_new_account(model) ⇒ Object
Request a new Avalara account
This API is for use by partner provisioning services customers only.
Avalara invites select partners to refer new customers to the AvaTax service using the onboarding features of AvaTax. These partners can create accounts for new customers using this API.
Calling this API creates an account with the specified product subscriptions, but does not configure billing. The customer will receive information from Avalara about how to configure billing for their account. You should call this API when a customer has requested to begin using Avalara services.
If the newly created account owner wishes, they can confirm that they have read and agree to the Avalara
terms and conditions. If they do so, they can receive a license key as part of this API and their
API will be created in Active status. If the customer has not yet read and accepted these terms and
conditions, the account will be created in New status and they can receive a license key by logging
onto the AvaTax website and reviewing terms and conditions online.
In Sandbox environment, the account will always be created as a test account regardless of the IsTest parameter in the request.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AvaTaxOnlyAccountAdmin, AvaTaxOnlyCompanyAdmin, BatchServiceAdmin, CompanyAdmin, CSPTester, FirmAdmin, Registrar, ReturnsOnlyAccountAdmin, ReturnsOnlyCompanyAdmin, SiteAdmin, SSTAdmin, SystemAdmin, TechnicalSupportAdmin.
- This API is available by invitation only.
- This API is available by invitation only. To request access to this feature, please speak to a business development manager and request access to [Provisioning:RequestNewAccount]. Swagger Name: AvaTaxClient
34 35 |
# File 'lib/avatax/client/provisioning.rb', line 34 def request_new_account(model) path = "/api/v2/accounts/request" post(path, model, {}, AvaTax::VERSION) end |
#request_new_entitlement(id, offer) ⇒ Object
Request a new entitilement to an existing customer
This API is for use by partner provisioning services customers only. This allows the partners to add new entitlements to an existing customer.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AvaTaxOnlyAccountAdmin, AvaTaxOnlyCompanyAdmin, BatchServiceAdmin, CompanyAdmin, CSPTester, FirmAdmin, Registrar, ReturnsOnlyAccountAdmin, ReturnsOnlyCompanyAdmin, SiteAdmin, SSTAdmin, SystemAdmin, TechnicalSupportAdmin.
- This API is available by invitation only.
- This API is available by invitation only. To request access to this feature, please speak to a business development manager and request access to [Provisioning:RequestNewAccount]. Swagger Name: AvaTaxClient
51 52 |
# File 'lib/avatax/client/provisioning.rb', line 51 def request_new_entitlement(id, offer) path = "/api/v2/accounts/#{id}/entitlements/#{offer}" post(path, {}, {}, AvaTax::VERSION) end |