Module: AvaTax::Client::Certificates
- Defined in:
- lib/avatax/client/certificates.rb
Instance Method Summary collapse
-
#create_certificates(companyId, model, options = {}) ⇒ CertificateModel[]
Create certificates for this company.
-
#delete_certificate(companyId, id) ⇒ ErrorDetail[]
Revoke and delete a certificate.
-
#delete_certificate_custom_fields(companyId, id, model) ⇒ Object
Delete Certificate Custom Fields.
-
#download_certificate_image(companyId, id, options = {}) ⇒ Object
Download an image for this certificate.
-
#get_certificate(companyId, id, options = {}) ⇒ Object
Retrieve a single certificate.
-
#get_certificate_setup(companyId) ⇒ Object
Check a company's exemption certificate status.
-
#link_attributes_to_certificate(companyId, id, model) ⇒ FetchResult
Link attributes to a certificate.
-
#link_customers_to_certificate(companyId, id, model) ⇒ FetchResult
Link customers to a certificate.
-
#list_attributes_for_certificate(companyId, id) ⇒ FetchResult
List all attributes applied to this certificate.
-
#list_certificate_tax_types(companyId, options = {}) ⇒ FetchResult
List the certificate tax-type hierarchy available to this company.
-
#list_custom_fields_for_certificate(companyId, id) ⇒ Object
Retrieve Certificate Custom Fields.
-
#list_customers_for_certificate(companyId, id, options = {}) ⇒ FetchResult
List customers linked to this certificate.
-
#list_local_exempt_jurisdictions(companyId, options = {}) ⇒ FetchResult
List local exempt jurisdictions for a given exposure zone and tax code.
-
#query_certificates(companyId, options = {}) ⇒ FetchResult
List all certificates for a company.
-
#request_certificate_setup(companyId) ⇒ Object
Request setup of exemption certificates for this company.
-
#unlink_attributes_from_certificate(companyId, id, model) ⇒ FetchResult
Unlink attributes from a certificate.
-
#unlink_customers_from_certificate(companyId, id, model) ⇒ FetchResult
Unlink customers from a certificate.
-
#update_certificate(companyId, id, model) ⇒ Object
Update a single certificate.
-
#update_certificate_custom_fields(companyId, id, model) ⇒ Object
Update Certificate Custom Fields.
-
#upload_certificate_image(companyId, id) ⇒ String
Upload an image or PDF attachment for this certificate.
Instance Method Details
#create_certificates(companyId, model, options = {}) ⇒ CertificateModel[]
Create certificates for this company
Record one or more certificates document for this company.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
When you create a certificate, it will be processed by Avalara and will become available for use in calculating tax exemptions when processing is complete. For a certificate to be used in calculating exemptions, it must have the following:
- An exposure zone indicating where the certificate is valid
- A link to the customer that is allowed to use this certificate
- Your tax transaction must contain the correct customer code
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
If the users specified in the certificates do not exist, the API will create the user and link them to the certificate
Security Policies
- This API requires one of the following user roles: AccountAdmin, AvaTaxOnlyAccountAdmin, AvaTaxOnlyCompanyAdmin, BatchServiceAdmin, CompanyAdmin, CSPTester, ProStoresOperator, Registrar, ReturnsOnlyAccountAdmin, ReturnsOnlyCompanyAdmin, SiteAdmin, SSTAdmin, SystemAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
39 40 |
# File 'lib/avatax/client/certificates.rb', line 39 def create_certificates(companyId, model, ={}) path = "/api/v2/companies/#{companyId}/certificates" post(path, model, , AvaTax::VERSION) end |
#delete_certificate(companyId, id) ⇒ ErrorDetail[]
Revoke and delete a certificate
Revoke the certificate identified by this URL, then delete it.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
Revoked certificates can no longer be used.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
66 67 |
# File 'lib/avatax/client/certificates.rb', line 66 def delete_certificate(companyId, id) path = "/api/v2/companies/#{companyId}/certificates/#{id}" delete(path, {}, AvaTax::VERSION) end |
#delete_certificate_custom_fields(companyId, id, model) ⇒ Object
Delete Certificate Custom Fields
Deletes custom fields for a specified certificate.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
87 88 |
# File 'lib/avatax/client/certificates.rb', line 87 def delete_certificate_custom_fields(companyId, id, model) path = "/api/v2/companies/#{companyId}/certificates/#{id}/custom-fields" delete(path, model, {}, AvaTax::VERSION) end |
#download_certificate_image(companyId, id, options = {}) ⇒ Object
Download an image for this certificate
Download an image or PDF file for this certificate.
This API can be used to download either a single-page preview of the certificate or a full PDF document.
To retrieve a preview image, set the $type parameter to Jpeg and the $page parameter to 1.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
117 118 |
# File 'lib/avatax/client/certificates.rb', line 117 def download_certificate_image(companyId, id, ={}) path = "/api/v2/companies/#{companyId}/certificates/#{id}/attachment" get(path, , AvaTax::VERSION) end |
#get_certificate(companyId, id, options = {}) ⇒ Object
Retrieve a single certificate
Get the current certificate identified by this URL.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
You can use the $include parameter to fetch the following additional objects for expansion:
- customers - Retrieves the list of customers linked to the certificate.
- po_numbers - Retrieves all PO numbers tied to the certificate.
- attributes - Retrieves all attributes applied to the certificate.
- histories - Retrieves the certificate update history
- jobs - Retrieves the jobs for this certificate
- jobs.phases - Retrieves the jobs along with their phases
- jobs.tasks - Retrieves the jobs along with their phases and the tasks within each phase
- logs - Retrieves the certificate log
- invalid_reasons - Retrieves invalid reasons for this certificate if the certificate is invalid
- custom_fields - Retrieves custom fields set for this certificate
- jurisdictions - Retrieves the list of jurisdictions associated with the certificate
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
157 158 |
# File 'lib/avatax/client/certificates.rb', line 157 def get_certificate(companyId, id, ={}) path = "/api/v2/companies/#{companyId}/certificates/#{id}" get(path, , AvaTax::VERSION) end |
#get_certificate_setup(companyId) ⇒ Object
Check a company's exemption certificate status.
Checks whether this company is configured to use exemption certificates in AvaTax.
Exemption certificates are tracked through a different auditable data store than the one that
holds AvaTax transactions. To use the AvaTax exemption certificate document store, please call
GetCertificateSetup to see if your company is configured to use the exemption certificate
document store. To request setup, please call RequestCertificateSetup and your company will
be configured with data storage in the auditable certificate system.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
177 178 |
# File 'lib/avatax/client/certificates.rb', line 177 def get_certificate_setup(companyId) path = "/api/v2/companies/#{companyId}/certificates/setup" get(path, {}, AvaTax::VERSION) end |
#link_attributes_to_certificate(companyId, id, model) ⇒ FetchResult
Link attributes to a certificate
Link one or many attributes to a certificate.
A certificate may have multiple attributes that control its behavior. You may link or unlink attributes to a
certificate at any time. The full list of defined attributes may be found using ListCertificateAttributes.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
206 207 |
# File 'lib/avatax/client/certificates.rb', line 206 def link_attributes_to_certificate(companyId, id, model) path = "/api/v2/companies/#{companyId}/certificates/#{id}/attributes/link" post(path, model, {}, AvaTax::VERSION) end |
#link_customers_to_certificate(companyId, id, model) ⇒ FetchResult
Link customers to a certificate
Link one or more customers to an existing certificate.
Customers and certificates must be linked before a customer can make use of a certificate to obtain
a tax exemption in AvaTax. Since some certificates may cover more than one business entity, a certificate
can be connected to multiple customer records using the LinkCustomersToCertificate API.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
236 237 |
# File 'lib/avatax/client/certificates.rb', line 236 def link_customers_to_certificate(companyId, id, model) path = "/api/v2/companies/#{companyId}/certificates/#{id}/customers/link" post(path, model, {}, AvaTax::VERSION) end |
#list_attributes_for_certificate(companyId, id) ⇒ FetchResult
List all attributes applied to this certificate
Retrieve the list of attributes that are linked to this certificate.
A certificate may have multiple attributes that control its behavior. You may link or unlink attributes to a certificate at any time. The full list of defined attributes may be found using ListCertificateAttributes API.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
264 265 |
# File 'lib/avatax/client/certificates.rb', line 264 def list_attributes_for_certificate(companyId, id) path = "/api/v2/companies/#{companyId}/certificates/#{id}/attributes" get(path, {}, AvaTax::VERSION) end |
#list_certificate_tax_types(companyId, options = {}) ⇒ FetchResult
List the certificate tax-type hierarchy available to this company
Returns the TPS multi-tax type hierarchy that is applicable when configuring exemption
certificates for the given country. The returned tax types can be used to populate
taxTypeMappings entries on a certificate jurisdiction via POST / PUT certificate.
This endpoint is scoped to the certificate (CertCapture) domain and does not return the
generic AvaTax tax-type catalog. For the generic catalog see the Definitions APIs.
country is a mandatory query parameter.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
295 296 |
# File 'lib/avatax/client/certificates.rb', line 295 def list_certificate_tax_types(companyId, ={}) path = "/api/v2/companies/#{companyId}/certificates/taxtypes" get(path, , AvaTax::VERSION) end |
#list_custom_fields_for_certificate(companyId, id) ⇒ Object
Retrieve Certificate Custom Fields
This API is used to retrieve custom fields for a certificate.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
343 344 |
# File 'lib/avatax/client/certificates.rb', line 343 def list_custom_fields_for_certificate(companyId, id) path = "/api/v2/companies/#{companyId}/certificates/#{id}/custom-fields" get(path, {}, AvaTax::VERSION) end |
#list_customers_for_certificate(companyId, id, options = {}) ⇒ FetchResult
List customers linked to this certificate
List all customers linked to this certificate.
Customers must be linked to a certificate in order to make use of its tax exemption features. You can link or unlink customers to a certificate at any time.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
324 325 |
# File 'lib/avatax/client/certificates.rb', line 324 def list_customers_for_certificate(companyId, id, ={}) path = "/api/v2/companies/#{companyId}/certificates/#{id}/customers" get(path, , AvaTax::VERSION) end |
#list_local_exempt_jurisdictions(companyId, options = {}) ⇒ FetchResult
List local exempt jurisdictions for a given exposure zone and tax code
Returns the list of jurisdictions that are valid for a given combination of exposure zone and exemption tax code. The returned jurisdictions can be used to add valid jurisdictions to a certificate.
Both exposureZone and taxCode are mandatory query parameters.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
372 373 |
# File 'lib/avatax/client/certificates.rb', line 372 def list_local_exempt_jurisdictions(companyId, ={}) path = "/api/v2/companies/#{companyId}/jurisdictions" get(path, , AvaTax::VERSION) end |
#query_certificates(companyId, options = {}) ⇒ FetchResult
List all certificates for a company
List all certificates recorded by a company
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
You can use the $include parameter to fetch the following additional objects for expansion:
- customers - Retrieves the list of customers linked to the certificate.
- po_numbers - Retrieves all PO numbers tied to the certificate.
- attributes - Retrieves all attributes applied to the certificate.
- histories - Retrieves the certificate update history
- jobs - Retrieves the jobs for this certificate
- jobs.phases - Retrieves the jobs along with their phases
- jobs.tasks - Retrieves the jobs along with their phases and the tasks within each phase
- logs - Retrieves the certificate log
- invalid_reasons - Retrieves invalid reasons for this certificate if the certificate is invalid
- custom_fields - Retrieves custom fields set for this certificate
- jurisdictions - Retrieves the list of jurisdictions associated with the certificate
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
415 416 |
# File 'lib/avatax/client/certificates.rb', line 415 def query_certificates(companyId, ={}) path = "/api/v2/companies/#{companyId}/certificates" get(path, , AvaTax::VERSION) end |
#request_certificate_setup(companyId) ⇒ Object
Request setup of exemption certificates for this company.
Requests the setup of exemption certificates for this company.
Exemption certificates are tracked through a different auditable data store than the one that
holds AvaTax transactions. To use the AvaTax exemption certificate document store, please call
GetCertificateSetup to see if your company is configured to use the exemption certificate
document store. To request setup, please call RequestCertificateSetup and your company will
be configured with data storage in the auditable certificate system.
This API will return the current status of exemption certificate setup for this company.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
437 438 |
# File 'lib/avatax/client/certificates.rb', line 437 def request_certificate_setup(companyId) path = "/api/v2/companies/#{companyId}/certificates/setup" post(path, {}, {}, AvaTax::VERSION) end |
#unlink_attributes_from_certificate(companyId, id, model) ⇒ FetchResult
Unlink attributes from a certificate
Unlink one or many attributes from a certificate.
A certificate may have multiple attributes that control its behavior. You may link or unlink attributes to a
certificate at any time. The full list of defined attributes may be found using ListCertificateAttributes.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
466 467 |
# File 'lib/avatax/client/certificates.rb', line 466 def unlink_attributes_from_certificate(companyId, id, model) path = "/api/v2/companies/#{companyId}/certificates/#{id}/attributes/unlink" post(path, model, {}, AvaTax::VERSION) end |
#unlink_customers_from_certificate(companyId, id, model) ⇒ FetchResult
Unlink customers from a certificate
Unlinks one or more customers from a certificate.
Unlinking a certificate from a customer will prevent the certificate from being used to generate tax exemptions for the customer in the future. If any previous transactions for this customer had used this linked certificate, those transactions will be unchanged and will still have a link to the exemption certificate in question.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
497 498 |
# File 'lib/avatax/client/certificates.rb', line 497 def unlink_customers_from_certificate(companyId, id, model) path = "/api/v2/companies/#{companyId}/certificates/#{id}/customers/unlink" post(path, model, {}, AvaTax::VERSION) end |
#update_certificate(companyId, id, model) ⇒ Object
Update a single certificate
Replace the certificate identified by this URL with a new one.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
523 524 |
# File 'lib/avatax/client/certificates.rb', line 523 def update_certificate(companyId, id, model) path = "/api/v2/companies/#{companyId}/certificates/#{id}" put(path, model, {}, AvaTax::VERSION) end |
#update_certificate_custom_fields(companyId, id, model) ⇒ Object
Update Certificate Custom Fields
Updates the values of custom fields for a certificate
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
544 545 |
# File 'lib/avatax/client/certificates.rb', line 544 def update_certificate_custom_fields(companyId, id, model) path = "/api/v2/companies/#{companyId}/certificates/#{id}/custom-fields" put(path, model, {}, AvaTax::VERSION) end |
#upload_certificate_image(companyId, id) ⇒ String
Upload an image or PDF attachment for this certificate
Upload an image or PDF attachment for this certificate.
Image attachments can be of the format PDF, JPEG, TIFF, or PNG. To upload a multi-page image, please
use the PDF data type.
A certificate is a document stored in either AvaTax Exemptions or CertCapture. The certificate document can contain information about a customer's eligibility for exemption from sales or use taxes based on criteria you specify when you store the certificate. To view or manage your certificates directly, please log onto the administrative website for the product you purchased.
Before you can use any exemption certificates endpoints, you must set up your company for exemption certificate data storage.
Companies that do not have this storage system set up will see CertCaptureNotConfiguredError when they call exemption
certificate related APIs. To check if this is set up for a company, call GetCertificateSetup. To request setup of exemption
certificate storage for this company, call RequestCertificateSetup.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPTester, SSTAdmin, TechnicalSupportAdmin, TechnicalSupportUser.
- This API depends on the following active services:Required (all): AvaTaxPro, ECMEssentials, ECMPro, ECMPremium, VEMPro, VEMPremium, ECMProComms, ECMPremiumComms. Swagger Name: AvaTaxClient
573 574 |
# File 'lib/avatax/client/certificates.rb', line 573 def upload_certificate_image(companyId, id) path = "/api/v2/companies/#{companyId}/certificates/#{id}/attachment" post(path, {}, {}, AvaTax::VERSION) end |