Module: AvaTax::Client::ItemsReverseSync
- Defined in:
- lib/avatax/client/itemsreversesync.rb
Instance Method Summary collapse
-
#create_reverse_sync_registration(companyId, model) ⇒ Object
Create a webhook registration for a company.
-
#delete_reverse_sync_registration(companyId, registrationId) ⇒ ObjectDeletedErrorModel[]
Delete a webhook registration.
-
#get_reverse_sync_registration(companyId, registrationId) ⇒ Object
Retrieve a webhook registration.
-
#list_reverse_sync_registrations(companyId) ⇒ FetchResult
List webhook registrations for a company.
-
#update_reverse_sync_registration(companyId, registrationId, model) ⇒ Object
Update a webhook registration.
Instance Method Details
#create_reverse_sync_registration(companyId, model) ⇒ Object
Create a webhook registration for a company.
Creates a webhook registration for the specified company. The registration defines a connector, callback URL, registration type, and subscribed events.
The customer must pass the connector name in connectorName; this value is also
used as the OAuth scope for the registration.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AvaTaxOnlyAccountAdmin, AvaTaxOnlyCompanyAdmin, BatchServiceAdmin, CompanyAdmin, CSPTester, SSTAdmin, TechnicalSupportAdmin. Swagger Name: AvaTaxClient
21 22 |
# File 'lib/avatax/client/itemsreversesync.rb', line 21 def create_reverse_sync_registration(companyId, model) path = "/api/v2/connector-sync/companies/#{companyId}/registrations" post(path, model, {}, AvaTax::VERSION) end |
#delete_reverse_sync_registration(companyId, registrationId) ⇒ ObjectDeletedErrorModel[]
Delete a webhook registration.
Deletes the webhook registration identified by the specified registration ID for the given company.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AvaTaxOnlyAccountAdmin, AvaTaxOnlyCompanyAdmin, BatchServiceAdmin, CompanyAdmin, CSPTester, SSTAdmin, TechnicalSupportAdmin. Swagger Name: AvaTaxClient
35 36 |
# File 'lib/avatax/client/itemsreversesync.rb', line 35 def delete_reverse_sync_registration(companyId, registrationId) path = "/api/v2/connector-sync/companies/#{companyId}/registrations/#{registrationId}" delete(path, {}, AvaTax::VERSION) end |
#get_reverse_sync_registration(companyId, registrationId) ⇒ Object
Retrieve a webhook registration.
Returns the webhook registration identified by the specified registration ID for the given company.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPAdmin, CSPTester, ReturnsOnlyAccountAdmin, ReturnsOnlyAccountUser, ReturnsOnlyCompanyAdmin, ReturnsOnlyCompanyUser, SiteAdmin, SSTAdmin, SystemAdmin, TechnicalSupportAdmin, TechnicalSupportUser. Swagger Name: AvaTaxClient
49 50 |
# File 'lib/avatax/client/itemsreversesync.rb', line 49 def get_reverse_sync_registration(companyId, registrationId) path = "/api/v2/connector-sync/companies/#{companyId}/registrations/#{registrationId}" get(path, {}, AvaTax::VERSION) end |
#list_reverse_sync_registrations(companyId) ⇒ FetchResult
List webhook registrations for a company.
Returns all webhook registrations for the specified company.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, AvaTaxOnlyAccountAdmin, AvaTaxOnlyAccountUser, AvaTaxOnlyCompanyAdmin, AvaTaxOnlyCompanyUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, CSPAdmin, CSPTester, ReturnsOnlyAccountAdmin, ReturnsOnlyAccountUser, ReturnsOnlyCompanyAdmin, ReturnsOnlyCompanyUser, SiteAdmin, SSTAdmin, SystemAdmin, TechnicalSupportAdmin, TechnicalSupportUser. Swagger Name: AvaTaxClient
62 63 |
# File 'lib/avatax/client/itemsreversesync.rb', line 62 def list_reverse_sync_registrations(companyId) path = "/api/v2/connector-sync/companies/#{companyId}/registrations" get(path, {}, AvaTax::VERSION) end |
#update_reverse_sync_registration(companyId, registrationId, model) ⇒ Object
Update a webhook registration.
Updates the webhook registration with the provided fields. Only the fields included in the request body are updated.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AvaTaxOnlyAccountAdmin, AvaTaxOnlyCompanyAdmin, BatchServiceAdmin, CompanyAdmin, CSPTester, SSTAdmin, TechnicalSupportAdmin. Swagger Name: AvaTaxClient
78 79 |
# File 'lib/avatax/client/itemsreversesync.rb', line 78 def update_reverse_sync_registration(companyId, registrationId, model) path = "/api/v2/connector-sync/companies/#{companyId}/registrations/#{registrationId}" patch(path, model, {}, AvaTax::VERSION) end |