Method: AvaTax::Client::MultiDocument#void_multi_document_transaction
- Defined in:
- lib/avatax/client/multidocument.rb
#void_multi_document_transaction(code, type, model) ⇒ Object
Void a MultiDocument transaction
Voids the current transaction uniquely identified by this URL.
A transaction represents a unique potentially taxable action that your company has recorded, and transactions include actions like sales, purchases, inventory transfer, and returns (also called refunds).
When you void a transaction, that transaction's status is recorded as DocVoided.
Transactions that have been previously reported to a tax authority by Avalara Managed Returns Service are considered locked,
and they are no longer available to be voided.
NOTE: If your companyCode or transactionCode contains any of these characters /, +, ? or a space please use the following encoding before making a request:
- Replace '/' with '_-ava2f-_' For example: document/Code becomes document_-ava2f-_Code
- Replace '+' with '_-ava2b-_' For example: document+Code becomes document_-ava2b-_Code
- Replace '?' with '_-ava3f-_' For example: document?Code becomes document_-ava3f-_Code
- Replace '%' with '_-ava25-_' For example: document%Code becomes document_-ava25-_Code
- Replace '#' with '_-ava23-_' For example: document#Code becomes document_-ava23-_Code
- Replace ' ' with '%20' For example: document Code becomes document%20Code
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, BatchServiceAdmin, CompanyAdmin, CSPTester, ProStoresOperator, SSTAdmin, TechnicalSupportAdmin.
- This API depends on the following active services:Required (all): AvaTaxPro. Swagger Name: AvaTaxClient
397 398 |
# File 'lib/avatax/client/multidocument.rb', line 397 def void_multi_document_transaction(code, type, model) path = "/api/v2/transactions/multidocument/#{code}/type/#{type}/void" post(path, model, {}, AvaTax::VERSION) end |