Method: AvaTax::Client::Notifications#list_notifications
- Defined in:
- lib/avatax/client/notifications.rb
#list_notifications(options = {}) ⇒ FetchResult
List all notifications.
List all notifications.
A notification is a message from Avalara that may have relevance to your business. You may want to regularly review notifications and then dismiss them when you are certain that you have addressed any relevant concerns raised by this notification.
An example of a notification would be a message about new software, or a change to AvaTax that may affect you, or a potential issue with your company's tax profile.
You may search for specific objects using the criteria in the $filter parameter; full documentation is available on Filtering in REST .
Paginate your results using the $top, $skip, and $orderby parameters.
Security Policies
- This API requires one of the following user roles: AccountAdmin, AccountOperator, AccountUser, BatchServiceAdmin, CompanyAdmin, CompanyUser, Compliance Root User, ComplianceAdmin, ComplianceUser, CSPAdmin, CSPTester, ECMAccountUser, ECMCompanyUser, FirmAdmin, FirmUser, ProStoresOperator, Registrar, SiteAdmin, SSTAdmin, SystemAdmin, TechnicalSupportAdmin, TechnicalSupportUser, TreasuryAdmin, TreasuryUser. Swagger Name: AvaTaxClient
75 76 |
# File 'lib/avatax/client/notifications.rb', line 75 def list_notifications(={}) path = "/api/v2/notifications" get(path, , AvaTax::VERSION) end |